@@ -32,8 +32,9 @@ public class V3PGReplicationStream implements PGReplicationStream {
   private final CopyDual copyDual;
   private final long updateInterval;
   private final ReplicationType replicationType;
+  private final boolean automaticFlush;
   private long lastStatusUpdate;
-  private boolean closeFlag = false;
+  private boolean closeFlag;
 
   private LogSequenceNumber lastServerLSN = LogSequenceNumber.INVALID_LSN;
   /**
@@ -58,12 +59,13 @@ public class V3PGReplicationStream implements PGReplicationStream {
    * @param replicationType  LOGICAL or PHYSICAL
    */
   public V3PGReplicationStream(CopyDual copyDual, LogSequenceNumber startLSN, long updateIntervalMs,
-      ReplicationType replicationType
+      boolean automaticFlush, ReplicationType replicationType
   ) {
     this.copyDual = copyDual;
     this.updateInterval = updateIntervalMs * NANOS_PER_MILLISECOND;
     this.lastStatusUpdate = System.nanoTime() - (updateIntervalMs * NANOS_PER_MILLISECOND);
     this.lastReceiveLSN = startLSN;
+    this.automaticFlush = automaticFlush;
     this.replicationType = replicationType;
   }
 
@@ -79,6 +81,7 @@ public class V3PGReplicationStream implements PGReplicationStream {
     return payload;
   }
 
+  @Override
   public /* @Nullable */ ByteBuffer readPending() throws SQLException {
     checkClose();
     return readInternal(false);
@@ -209,8 +212,10 @@ public class V3PGReplicationStream implements PGReplicationStream {
         TimeUnit.MICROSECONDS);
 
     if (LOGGER.isLoggable(Level.FINEST)) {
+      @SuppressWarnings("JavaUtilDate")
+      Date clock = new Date(now);
       LOGGER.log(Level.FINEST, " FE=> StandbyStatusUpdate(received: {0}, flushed: {1}, applied: {2}, clock: {3})",
-          new Object[]{received.asString(), flushed.asString(), applied.asString(), new Date(now)});
+          new Object[]{received.asString(), flushed.asString(), applied.asString(), clock});
     }
 
     byteBuffer.put((byte) 'r');
@@ -221,7 +226,7 @@ public class V3PGReplicationStream implements PGReplicationStream {
     if (replyRequired) {
       byteBuffer.put((byte) 1);
     } else {
-      byteBuffer.put(received == LogSequenceNumber.INVALID_LSN ? (byte) 1 : (byte) 0);
+      byteBuffer.put(received.equals(LogSequenceNumber.INVALID_LSN) ? (byte) 1 : (byte) 0);
     }
 
     lastStatusUpdate = now;
@@ -235,7 +240,7 @@ public class V3PGReplicationStream implements PGReplicationStream {
     }
     // if the client has confirmed flush of last XLogData msg and KeepAlive shows ServerLSN is still
     // advancing, we can safely advance FlushLSN to ServerLSN
-    if (explicitlyFlushedLSN.asLong() >= startOfLastMessageLSN.asLong()
+    if (automaticFlush && explicitlyFlushedLSN.asLong() >= startOfLastMessageLSN.asLong()
         && lastServerLSN.asLong() > explicitlyFlushedLSN.asLong()
         && lastServerLSN.asLong() > lastFlushedLSN.asLong()) {
       lastFlushedLSN = lastServerLSN;
@@ -246,6 +251,7 @@ public class V3PGReplicationStream implements PGReplicationStream {
     boolean replyRequired = buffer.get() != 0;
 
     if (LOGGER.isLoggable(Level.FINEST)) {
+      @SuppressWarnings("JavaUtilDate")
       Date clockTime = new Date(
           TimeUnit.MILLISECONDS.convert(lastServerClock, TimeUnit.MICROSECONDS)
           + POSTGRES_EPOCH_2000_01_01);
@@ -262,14 +268,11 @@ public class V3PGReplicationStream implements PGReplicationStream {
     lastServerLSN = LogSequenceNumber.valueOf(buffer.getLong());
     long systemClock = buffer.getLong();
 
-    switch (replicationType) {
-      case LOGICAL:
-        lastReceiveLSN = LogSequenceNumber.valueOf(startLsn);
-        break;
-      case PHYSICAL:
-        int payloadSize = buffer.limit() - buffer.position();
-        lastReceiveLSN = LogSequenceNumber.valueOf(startLsn + payloadSize);
-        break;
+    if (replicationType == ReplicationType.LOGICAL) {
+      lastReceiveLSN = LogSequenceNumber.valueOf(startLsn);
+    } else if (replicationType == ReplicationType.PHYSICAL) {
+      int payloadSize = buffer.limit() - buffer.position();
+      lastReceiveLSN = LogSequenceNumber.valueOf(startLsn + payloadSize);
     }
 
     if (LOGGER.isLoggable(Level.FINEST)) {
@@ -287,6 +290,7 @@ public class V3PGReplicationStream implements PGReplicationStream {
     }
   }
 
+  @Override
   public void close() throws SQLException {
     if (isClosed()) {
       return;
