@@ -9,6 +9,7 @@ import static org.postgresql.util.internal.Nullness.castNonNull;
 
 import org.postgresql.ds.common.BaseDataSource;
 import org.postgresql.jdbc.ResourceLock;
+import org.postgresql.util.DriverInfo;
 import org.postgresql.util.GT;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
@@ -17,7 +18,8 @@ import org.postgresql.util.PSQLState;
 
 import java.sql.Connection;
 import java.sql.SQLException;
-import java.util.Stack;
+import java.util.ArrayDeque;
+import java.util.Deque;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.TimeUnit;
@@ -67,7 +69,7 @@ import javax.sql.PooledConnection;
 @Deprecated
 public class PGPoolingDataSource extends BaseDataSource implements DataSource {
   protected static ConcurrentMap<String, PGPoolingDataSource> dataSources =
-      new ConcurrentHashMap<String, PGPoolingDataSource>();
+      new ConcurrentHashMap<>();
 
   public static /* @Nullable */ PGPoolingDataSource getDataSource(String name) {
     return dataSources.get(name);
@@ -75,12 +77,12 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
 
   // Additional Data Source properties
   protected /* @Nullable */ String dataSourceName; // Must be protected for subclasses to sync updates to it
-  private int initialConnections = 0;
-  private int maxConnections = 0;
+  private int initialConnections;
+  private int maxConnections;
   // State variables
-  private boolean initialized = false;
-  private final Stack<PooledConnection> available = new Stack<PooledConnection>();
-  private final Stack<PooledConnection> used = new Stack<PooledConnection>();
+  private boolean initialized;
+  private final Deque<PooledConnection> available = new ArrayDeque<>();
+  private final Deque<PooledConnection> used = new ArrayDeque<>();
   private boolean isClosed;
   private final ResourceLock lock = new ResourceLock();
   private final Condition lockCondition = lock.newCondition();
@@ -89,8 +91,9 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
   /**
    * Gets a description of this DataSource.
    */
+  @Override
   public String getDescription() {
-    return "Pooling DataSource '" + dataSourceName + " from " + org.postgresql.util.DriverInfo.DRIVER_FULL_NAME;
+    return "Pooling DataSource '" + dataSourceName + " from " + DriverInfo.DRIVER_FULL_NAME;
   }
 
   /**
@@ -99,6 +102,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws IllegalStateException The Server Name cannot be changed after the DataSource has been
    *         used.
    */
+  @Override
   public void setServerName(String serverName) {
     if (initialized) {
       throw new IllegalStateException(
@@ -113,6 +117,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws IllegalStateException The Database Name cannot be changed after the DataSource has been
    *         used.
    */
+  @Override
   public void setDatabaseName(/* @Nullable */ String databaseName) {
     if (initialized) {
       throw new IllegalStateException(
@@ -126,6 +131,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    *
    * @throws IllegalStateException The User cannot be changed after the DataSource has been used.
    */
+  @Override
   public void setUser(/* @Nullable */ String user) {
     if (initialized) {
       throw new IllegalStateException(
@@ -140,6 +146,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws IllegalStateException The Password cannot be changed after the DataSource has been
    *         used.
    */
+  @Override
   public void setPassword(/* @Nullable */ String password) {
     if (initialized) {
       throw new IllegalStateException(
@@ -154,6 +161,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws IllegalStateException The Port Number cannot be changed after the DataSource has been
    *         used.
    */
+  @Override
   public void setPortNumber(int portNumber) {
     if (initialized) {
       throw new IllegalStateException(
@@ -309,6 +317,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws SQLException Occurs when no pooled connection is available, and a new physical
    *         connection cannot be created.
    */
+  @Override
   public Connection getConnection(/* @Nullable */ String user, /* @Nullable */ String password)
       throws SQLException {
     // If this is for the default user/password, use a pooled connection
@@ -330,6 +339,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * @throws SQLException Occurs when no pooled connection is available, and a new physical
    *         connection cannot be created.
    */
+  @Override
   public Connection getConnection() throws SQLException {
     if (!initialized) {
       initialize();
@@ -348,6 +358,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
         try {
           pci.close();
         } catch (SQLException ignored) {
+          // We can't do much if the connection close fails, try closing the rest
         }
       }
       while (!used.isEmpty()) {
@@ -356,6 +367,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
         try {
           pci.close();
         } catch (SQLException ignored) {
+          // We can't do much if the connection close fails, try closing the rest
         }
       }
     }
@@ -396,6 +408,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
             // Wake up every second at a minimum
             lockCondition.await(1000L, TimeUnit.MILLISECONDS);
           } catch (InterruptedException ignored) {
+            // Retry later
           }
         }
       }
@@ -409,6 +422,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
    * This is the only way connections are marked as unused.
    */
   private final ConnectionEventListener connectionEventListener = new ConnectionEventListener() {
+    @Override
     public void connectionClosed(ConnectionEvent event) {
       ((PooledConnection) event.getSource()).removeConnectionEventListener(this);
       try (ResourceLock ignore = lock.obtain()) {
@@ -430,6 +444,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
      * This is only called for fatal errors, where the physical connection is useless afterward and
      * should be removed from the pool.
      */
+    @Override
     public void connectionErrorOccurred(ConnectionEvent event) {
       ((PooledConnection) event.getSource()).removeConnectionEventListener(this);
       try (ResourceLock ignore = lock.obtain()) {
@@ -446,6 +461,7 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
   /**
    * Adds custom properties for this DataSource to the properties defined in the superclass.
    */
+  @Override
   public Reference getReference() throws NamingException {
     Reference ref = super.getReference();
     ref.add(new StringRefAddr("dataSourceName", dataSourceName));
@@ -458,10 +474,12 @@ public class PGPoolingDataSource extends BaseDataSource implements DataSource {
     return ref;
   }
 
+  @Override
   public boolean isWrapperFor(Class<?> iface) throws SQLException {
     return iface.isAssignableFrom(getClass());
   }
 
+  @Override
   public <T> T unwrap(Class<T> iface) throws SQLException {
     if (iface.isAssignableFrom(getClass())) {
       return iface.cast(this);
