@@ -71,8 +71,8 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
       Class.forName("org.postgresql.Driver");
     } catch (ClassNotFoundException e) {
       throw new IllegalStateException(
-        "BaseDataSource is unable to load org.postgresql.Driver. Please check if you have proper PostgreSQL JDBC Driver jar on the classpath",
-        e);
+          "BaseDataSource is unable to load org.postgresql.Driver. Please check if you have proper PostgreSQL JDBC Driver jar on the classpath",
+          e);
     }
   }
 
@@ -463,6 +463,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.SEND_BUFFER_SIZE.set(properties, nbytes);
   }
 
+  /**
+   * @return send max buffer size
+   * @see PGProperty#MAX_SEND_BUFFER_SIZE
+   */
+  public int getMaxSendBufferSize() {
+    return PGProperty.MAX_SEND_BUFFER_SIZE.getIntNoCheck(properties);
+  }
+
+  /**
+   * @param nbytes send max buffer size
+   * @see PGProperty#MAX_SEND_BUFFER_SIZE
+   */
+  public void setMaxSendBufferSize(int nbytes) {
+    PGProperty.MAX_SEND_BUFFER_SIZE.set(properties, nbytes);
+  }
+
   /**
    * @param count prepare threshold
    * @see PGProperty#PREPARE_THRESHOLD
@@ -742,6 +758,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.SSL_ROOT_CERT.set(properties, file);
   }
 
+  /**
+   * @param sslNegotiation one of SSLNegotiation.POSTGRES or SSLNegotiation.DIRECT
+   * @see PGProperty#SSL_NEGOTIATION
+   */
+  public void setSslNegotiation(/* @Nullable */ String sslNegotiation) {
+    PGProperty.SSL_NEGOTIATION.set(properties, sslNegotiation);
+  }
+
+  /**
+   * @return SSL Negotiation scheme
+   * @see PGProperty#SSL_NEGOTIATION
+   */
+  public String getSslNegotiation() {
+    return castNonNull(PGProperty.SSL_NEGOTIATION.getOrDefault(properties));
+  }
+
   /**
    * @return SSL password
    * @see PGProperty#SSL_PASSWORD
@@ -958,6 +990,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.DISABLE_COLUMN_SANITISER.set(properties, disableColumnSanitiser);
   }
 
+  /**
+   * @return convertBooleanToNumeric
+   * @see PGProperty#CONVERT_BOOLEAN_TO_NUMERIC
+   */
+  public boolean getConvertBooleanToNumeric() {
+    return PGProperty.CONVERT_BOOLEAN_TO_NUMERIC.getBoolean(properties);
+  }
+
+  /**
+   * @param convertBooleanToNumeric convertBooleanToNumeric
+   * @see PGProperty#CONVERT_BOOLEAN_TO_NUMERIC
+   */
+  public void setConvertBooleanToNumeric(boolean convertBooleanToNumeric) {
+    PGProperty.CONVERT_BOOLEAN_TO_NUMERIC.set(properties, convertBooleanToNumeric);
+  }
+
   /**
    * @return current schema
    * @see PGProperty#CURRENT_SCHEMA
@@ -1060,7 +1108,9 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
    * parameters in a transaction
    * @return whether to group startup parameters or not
    * @see PGProperty#GROUP_STARTUP_PARAMETERS
+   * @deprecated since we can send the startup parameters as a multistatment transaction
    */
+  @Deprecated
   public boolean getGroupStartupParameters() {
     return PGProperty.GROUP_STARTUP_PARAMETERS.getBoolean(properties);
   }
@@ -1069,7 +1119,9 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
    *
    * @param groupStartupParameters whether to group startup Parameters in a transaction or not
    * @see PGProperty#GROUP_STARTUP_PARAMETERS
+   * @deprecated since we can send the startup parameters as a multistatment transaction
    */
+  @Deprecated
   public void setGroupStartupParameters(boolean groupStartupParameters) {
     PGProperty.GROUP_STARTUP_PARAMETERS.set(properties, groupStartupParameters);
   }
@@ -1106,6 +1158,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.JAAS_LOGIN.set(properties, doLogin);
   }
 
+  /**
+   * @return true if using default GSS credentials
+   * @see PGProperty#GSS_USE_DEFAULT_CREDS
+   */
+  public boolean getGssUseDefaultCreds() {
+    return PGProperty.GSS_USE_DEFAULT_CREDS.getBoolean(properties);
+  }
+
+  /**
+   * @param gssUseDefaultCreds true if using default GSS credentials
+   * @see PGProperty#GSS_USE_DEFAULT_CREDS
+   */
+  public void setGssUseDefaultCreds(boolean gssUseDefaultCreds) {
+    PGProperty.GSS_USE_DEFAULT_CREDS.set(properties, gssUseDefaultCreds);
+  }
+
   /**
    * @return Kerberos server name
    * @see PGProperty#KERBEROS_SERVER_NAME
@@ -1325,6 +1393,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.LOGGER_FILE.set(properties, loggerFile);
   }
 
+  /**
+   * @return Channel binding option
+   * @see PGProperty#CHANNEL_BINDING
+   */
+  public /* @Nullable */ String getChannelBinding() {
+    return PGProperty.CHANNEL_BINDING.getOrDefault(properties);
+  }
+
+  /**
+   * @param channelBinding Channel binding option
+   * @see PGProperty#CHANNEL_BINDING
+   */
+  public void setChannelBinding(/* @Nullable */ String channelBinding) {
+    PGProperty.CHANNEL_BINDING.set(properties, channelBinding);
+  }
+
   /**
    * Generates a {@link DriverManager} URL from the other properties supplied.
    *
