@@ -24,18 +24,12 @@ import java.util.Map;
 import java.util.logging.Level;
 
 /**
- * <p>This class implements the Fastpath api.</p>
+ * This class implements the Fastpath api.
  *
  * <p>This is a means of executing functions embedded in the backend from within a java application.</p>
  *
  * <p>It is based around the file src/interfaces/libpq/fe-exec.c</p>
- *
- * @deprecated This API is somewhat obsolete, as one may achieve similar performance
- *         and greater functionality by setting up a prepared statement to define
- *         the function call. Then, executing the statement with binary transmission of parameters
- *         and results substitutes for a fast-path function call.
  */
-@Deprecated
 public class Fastpath {
   // Java passes oids around as longs, but in the backend
   // it's an unsigned int, so we use this to make the conversion
@@ -101,13 +95,16 @@ public class Fastpath {
    */
   public byte /* @Nullable */ [] fastpath(int fnId, FastpathArg[] args) throws SQLException {
     // Turn fastpath array into a parameter list.
+    @SuppressWarnings("deprecation")
     ParameterList params = executor.createFastpathParameters(args.length);
     for (int i = 0; i < args.length; i++) {
       args[i].populateParameter(params, i + 1);
     }
 
     // Run it.
-    return executor.fastpathCall(fnId, params, connection.getAutoCommit());
+    @SuppressWarnings("deprecation")
+    byte[] result = executor.fastpathCall(fnId, params, connection.getAutoCommit());
+    return result;
   }
 
   /**
@@ -131,7 +128,7 @@ public class Fastpath {
   }
 
   /**
-   * <p>Send a function call to the PostgreSQL backend by name.</p>
+   * Send a function call to the PostgreSQL backend by name.
    *
    * <p>Note: the mapping for the procedure name to function id needs to exist, usually to an earlier
    * call to addfunction().</p>
@@ -232,7 +229,7 @@ public class Fastpath {
   }
 
   /**
-   * <p>This adds a function to our lookup table.</p>
+   * This adds a function to our lookup table.
    *
    * <p>User code should use the addFunctions method, which is based upon a query, rather than hard
    * coding the oid. The oid for a function is not guaranteed to remain static, even on different
@@ -246,8 +243,8 @@ public class Fastpath {
   }
 
   /**
-   * <p>This takes a ResultSet containing two columns. Column 1 contains the function name, Column 2
-   * the oid.</p>
+   * This takes a ResultSet containing two columns. Column 1 contains the function name, Column 2
+   * the oid.
    *
    * <p>It reads the entire ResultSet, loading the values into the function table.</p>
    *
@@ -280,7 +277,7 @@ public class Fastpath {
   }
 
   /**
-   * <p>This returns the function id associated by its name.</p>
+   * This returns the function id associated by its name.
    *
    * <p>If addFunction() or addFunctions() have not been called for this name, then an SQLException is
    * thrown.</p>
