@@ -10,6 +10,7 @@ import org.postgresql.core.Encoding;
 import org.postgresql.core.Oid;
 import org.postgresql.util.ByteConverter;
 import org.postgresql.util.GT;
+import org.postgresql.util.PGbytea;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 
@@ -49,6 +50,7 @@ import java.util.Map;
  */
 final class ArrayEncoding {
 
+  @SuppressWarnings("ExtendsObject")
   interface ArrayEncoder<A extends Object> {
 
     /**
@@ -123,6 +125,7 @@ final class ArrayEncoding {
    * @param <A>
    *          Base array type supported.
    */
+  @SuppressWarnings("ExtendsObject")
   private abstract static class AbstractArrayEncoder<A extends Object>
       implements ArrayEncoder<A> {
 
@@ -352,6 +355,7 @@ final class ArrayEncoding {
    * @param <A>
    *          The primitive array to support.
    */
+  @SuppressWarnings("ExtendsObject")
   private abstract static class FixedSizePrimitiveArrayEncoder<A extends Object>
       extends AbstractArrayEncoder<A> {
 
@@ -924,12 +928,6 @@ final class ArrayEncoding {
   private static final AbstractArrayEncoder<byte[][]> BYTEA_ARRAY = new AbstractArrayEncoder<byte[][]>(Oid.BYTEA,
       Oid.BYTEA_ARRAY) {
 
-    /**
-     * The possible characters to use for representing hex binary data.
-     */
-    private final char[] hexDigits = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd',
-        'e', 'f'};
-
     /**
      * {@inheritDoc}
      */
@@ -1025,14 +1023,7 @@ final class ArrayEncoding {
 
         if (array[i] != null) {
           sb.append("\"\\\\x");
-          for (int j = 0; j < array[i].length; j++) {
-            byte b = array[i][j];
-
-            // get the value for the left 4 bits (drop sign)
-            sb.append(hexDigits[(b & 0xF0) >>> 4]);
-            // get the value for the right 4 bits
-            sb.append(hexDigits[b & 0x0F]);
-          }
+          PGbytea.appendHexString(sb, array[i], 0, array[i].length);
           sb.append('"');
         } else {
           sb.append("NULL");
@@ -1128,7 +1119,7 @@ final class ArrayEncoding {
    *           if <i>array</i> is not a supported type.
    * @see ArrayEncoding.ArrayEncoder#supportBinaryRepresentation(int)
    */
-  @SuppressWarnings({"unchecked", "rawtypes"})
+  @SuppressWarnings({"unchecked", "rawtypes", "ExtendsObject"})
   public static <A extends Object> ArrayEncoder<A> getArrayEncoder(A array) throws PSQLException {
     final Class<?> arrayClazz = array.getClass();
     Class<?> subClazz = arrayClazz.getComponentType();
@@ -1177,6 +1168,7 @@ final class ArrayEncoding {
    * Wraps an {@link AbstractArrayEncoder} implementation and provides optimized
    * support for 2 dimensions.
    */
+  @SuppressWarnings("ExtendsObject")
   private static final class TwoDimensionPrimitiveArrayEncoder<A extends Object> implements ArrayEncoder<A[]> {
     private final AbstractArrayEncoder<A> support;
 
