@@ -5,17 +5,21 @@
 
 package org.postgresql.jdbc;
 
+import org.postgresql.core.BaseConnection;
 import org.postgresql.largeobject.LargeObject;
 
+import java.io.InputStream;
+import java.sql.Blob;
 import java.sql.SQLException;
 
-public class PgBlob extends AbstractBlobClob implements java.sql.Blob {
+public class PgBlob extends AbstractBlobClob implements Blob {
 
-  public PgBlob(org.postgresql.core.BaseConnection conn, long oid) throws SQLException {
+  public PgBlob(BaseConnection conn, long oid) throws SQLException {
     super(conn, oid);
   }
 
-  public java.io.InputStream getBinaryStream(long pos, long length)
+  @Override
+  public InputStream getBinaryStream(long pos, long length)
       throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
       checkFreed();
@@ -30,10 +34,12 @@ public class PgBlob extends AbstractBlobClob implements java.sql.Blob {
     }
   }
 
+  @Override
   public int setBytes(long pos, byte[] bytes) throws SQLException {
     return setBytes(pos, bytes, 0, bytes.length);
   }
 
+  @Override
   public int setBytes(long pos, byte[] bytes, int offset, int len)
       throws SQLException {
     try (ResourceLock ignore = lock.obtain()) {
