@@ -17,6 +17,7 @@ import org.postgresql.core.CachedQuery;
 import org.postgresql.core.ConnectionFactory;
 import org.postgresql.core.Encoding;
 import org.postgresql.core.Oid;
+import org.postgresql.core.ProtocolVersion;
 import org.postgresql.core.Query;
 import org.postgresql.core.QueryExecutor;
 import org.postgresql.core.ReplicationProtocol;
@@ -121,6 +122,7 @@ public class PgConnection implements BaseConnection {
           MethodHandles.lookup().findVirtual(securityManagerClass, "checkPermission",
               MethodType.methodType(void.class, Permission.class));
     } catch (NoSuchMethodException | IllegalAccessException | ClassNotFoundException ignore) {
+      // Ignore if the security manager is not available
     }
     SYSTEM_GET_SECURITY_MANAGER = systemGetSecurityManagerHandle;
     SECURITY_MANAGER_CHECK_PERMISSION = securityManagerCheckPermission;
@@ -202,6 +204,8 @@ public class PgConnection implements BaseConnection {
   private final boolean logServerErrorDetail;
   // Bind String to UNSPECIFIED or VARCHAR?
   private final boolean bindStringAsVarchar;
+  // Convert boolean values to numeric types?
+  private final boolean convertBooleanToNumeric;
 
   // Current warnings; there might be more on queryExecutor too.
   private /* @Nullable */ SQLWarning firstWarning;
@@ -217,6 +221,8 @@ public class PgConnection implements BaseConnection {
   private final /* @Nullable */ String xmlFactoryFactoryClass;
   private /* @Nullable */ PGXmlFactoryFactory xmlFactoryFactory;
   private final LazyCleaner.Cleanable<IOException> cleanable;
+  /* this is actually the database we are connected to */
+  private /* @Nullable */ String catalog;
 
   final CachedQuery borrowQuery(String sql) throws SQLException {
     return queryExecutor.borrowQuery(sql);
@@ -272,8 +278,8 @@ public class PgConnection implements BaseConnection {
     // Now make the initial connection and set up local state
     this.queryExecutor = ConnectionFactory.openConnection(hostSpecs, info);
 
-    // WARNING for unsupported servers (8.1 and lower are not supported)
-    if (LOGGER.isLoggable(Level.WARNING) && !haveMinimumServerVersion(ServerVersion.v8_2)) {
+    // WARNING for unsupported servers (9.0 and lower are not supported)
+    if (LOGGER.isLoggable(Level.WARNING) && !haveMinimumServerVersion(ServerVersion.v9_1)) {
       LOGGER.log(Level.WARNING, "Unsupported Server Version: {0}", queryExecutor.getServerVersion());
     }
 
@@ -359,6 +365,7 @@ public class PgConnection implements BaseConnection {
     finalizeAction = new PgConnectionCleaningAction(lock, openStackTrace, queryExecutor.getCloseAction());
     this.logServerErrorDetail = PGProperty.LOG_SERVER_ERROR_DETAIL.getBoolean(info);
     this.disableColumnSanitiser = PGProperty.DISABLE_COLUMN_SANITISER.getBoolean(info);
+    this.convertBooleanToNumeric = PGProperty.CONVERT_BOOLEAN_TO_NUMERIC.getBoolean(info);
 
     if (haveMinimumServerVersion(ServerVersion.v8_3)) {
       typeCache.addCoreType("uuid", Oid.UUID, Types.OTHER, "java.util.UUID", Oid.UUID_ARRAY);
@@ -481,7 +488,7 @@ public class PgConnection implements BaseConnection {
     return oids;
   }
 
-  private String oidsToString(Set<Integer> oids) {
+  private static String oidsToString(Set<Integer> oids) {
     StringBuilder sb = new StringBuilder();
     for (Integer oid : oids) {
       sb.append(Oid.toString(oid));
@@ -635,9 +642,9 @@ public class PgConnection implements BaseConnection {
   }
 
   /**
-   * <p>In SQL, a result table can be retrieved through a cursor that is named. The current row of a
+   * In SQL, a result table can be retrieved through a cursor that is named. The current row of a
    * result can be updated or deleted using a positioned update/delete statement that references the
-   * cursor name.</p>
+   * cursor name.
    *
    * <p>We do not support positioned update/delete, so this is a no-op.</p>
    *
@@ -661,8 +668,8 @@ public class PgConnection implements BaseConnection {
   }
 
   /**
-   * <p>We are required to bring back certain information by the DatabaseMetaData class. These
-   * functions do that.</p>
+   * We are required to bring back certain information by the DatabaseMetaData class. These
+   * functions do that.
    *
    * <p>Method getURL() brings back the URL (good job we saved it)</p>
    *
@@ -684,7 +691,6 @@ public class PgConnection implements BaseConnection {
   }
 
   @Override
-  @SuppressWarnings("deprecation") // support for deprecated Fastpath API
   public Fastpath getFastpathAPI() throws SQLException {
     checkClosed();
     if (fastpath == null) {
@@ -694,7 +700,6 @@ public class PgConnection implements BaseConnection {
   }
 
   // This holds a reference to the Fastpath API if already open
-  @SuppressWarnings("deprecation") // support for deprecated Fastpath API
   private /* @Nullable */ Fastpath fastpath;
 
   @Override
@@ -709,14 +714,14 @@ public class PgConnection implements BaseConnection {
   // This holds a reference to the LargeObject API if already open
   private /* @Nullable */ LargeObjectManager largeobject;
 
-  /*
+  /**
    * This method is used internally to return an object based around org.postgresql's more unique
    * data types.
    *
    * <p>It uses an internal HashMap to get the handling class. If the type is not supported, then an
    * instance of org.postgresql.util.PGobject is returned.
    *
-   * You can use the getValue() or setValue() methods to handle the returned object. Custom objects
+   * <p>You can use the getValue() or setValue() methods to handle the returned object. Custom objects
    * can have their own methods.
    *
    * @return PGobject for this type, and set to value
@@ -787,6 +792,7 @@ public class PgConnection implements BaseConnection {
   }
 
   @Override
+  @Deprecated
   public void addDataType(String type, String name) {
     try {
       addDataType(type, Class.forName(name).asSubclass(PGobject.class));
@@ -1112,7 +1118,16 @@ public class PgConnection implements BaseConnection {
   @Override
   public String getCatalog() throws SQLException {
     checkClosed();
-    return queryExecutor.getDatabase();
+    String catalog = this.catalog;
+    if (catalog == null) {
+      try (Statement stmt = createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
+            ResultSet rs = stmt.executeQuery("select current_catalog")) {
+        if (rs.next()) {
+          this.catalog = catalog = rs.getString(1);
+        }
+      }
+    }
+    return castNonNull(catalog);
   }
 
   public boolean getHideUnprivilegedObjects() {
@@ -1244,7 +1259,7 @@ public class PgConnection implements BaseConnection {
   @Override
   public void setDefaultFetchSize(int fetchSize) throws SQLException {
     if (fetchSize < 0) {
-      throw new PSQLException(GT.tr("Fetch size must be a value greater to or equal to 0."),
+      throw new PSQLException(GT.tr("Fetch size must be a value greater than or equal to 0."),
           PSQLState.INVALID_PARAMETER_VALUE);
     }
 
@@ -1281,7 +1296,7 @@ public class PgConnection implements BaseConnection {
     return LOGGER;
   }
 
-  public int getProtocolVersion() {
+  public ProtocolVersion getProtocolVersion() {
     return queryExecutor.getProtocolVersion();
   }
 
@@ -1408,16 +1423,14 @@ public class PgConnection implements BaseConnection {
   public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency,
       int resultSetHoldability) throws SQLException {
     checkClosed();
-    return new PgPreparedStatement(this, sql, resultSetType, resultSetConcurrency,
-        resultSetHoldability);
+    return new PgPreparedStatement(this, sql, resultSetType, resultSetConcurrency, resultSetHoldability);
   }
 
   @Override
   public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency,
       int resultSetHoldability) throws SQLException {
     checkClosed();
-    return new PgCallableStatement(this, sql, resultSetType, resultSetConcurrency,
-        resultSetHoldability);
+    return new PgCallableStatement(this, sql, resultSetType, resultSetConcurrency, resultSetHoldability);
   }
 
   @Override
@@ -1541,7 +1554,7 @@ public class PgConnection implements BaseConnection {
           }
         } else {
           try (Statement checkConnectionQuery = createStatement()) {
-            ((PgStatement)checkConnectionQuery).execute("", QueryExecutor.QUERY_EXECUTE_AS_SIMPLE);
+            ((PgStatement)checkConnectionQuery).executeWithFlags("", QueryExecutor.QUERY_EXECUTE_AS_SIMPLE);
           }
         }
         return true;
@@ -1653,6 +1666,11 @@ public class PgConnection implements BaseConnection {
     return logServerErrorDetail;
   }
 
+  @Override
+  public boolean getConvertBooleanToNumeric() {
+    return convertBooleanToNumeric;
+  }
+
   @Override
   public boolean isWrapperFor(Class<?> iface) throws SQLException {
     checkClosed();
@@ -1714,7 +1732,7 @@ public class PgConnection implements BaseConnection {
       return;
     }
 
-    SQL_PERMISSION_ABORT.checkGuard(this);
+    checkPermission(SQL_PERMISSION_ABORT);
 
     AbortCommand command = new AbortCommand();
     executor.execute(command);
@@ -1740,7 +1758,7 @@ public class PgConnection implements BaseConnection {
     }
   }
 
-  private void checkPermission(SQLPermission sqlPermissionNetworkTimeout) {
+  private static void checkPermission(SQLPermission sqlPermissionNetworkTimeout) {
     if (SYSTEM_GET_SECURITY_MANAGER != null && SECURITY_MANAGER_CHECK_PERMISSION != null) {
       try {
         Object securityManager = SYSTEM_GET_SECURITY_MANAGER.invoke();
@@ -1948,7 +1966,7 @@ public class PgConnection implements BaseConnection {
             GT.tr("Could not instantiate xmlFactoryFactory: {0}", xmlFactoryFactoryClass),
             PSQLState.INVALID_PARAMETER_VALUE, ex);
       }
-      if (!clazz.isAssignableFrom(PGXmlFactoryFactory.class)) {
+      if (!PGXmlFactoryFactory.class.isAssignableFrom(clazz)) {
         throw new PSQLException(
             GT.tr("Connection property xmlFactoryFactory must implement PGXmlFactoryFactory: {0}", xmlFactoryFactoryClass),
             PSQLState.INVALID_PARAMETER_VALUE);
