@@ -21,6 +21,7 @@ import org.postgresql.fastpath.Fastpath;
 import org.postgresql.jdbc.FieldMetadata.Key;
 import org.postgresql.largeobject.LargeObjectManager;
 import org.postgresql.replication.PGReplicationConnection;
+import org.postgresql.test.annotations.tags.Arrays;
 import org.postgresql.util.LruCache;
 import org.postgresql.util.PGobject;
 import org.postgresql.xml.PGXmlFactoryFactory;
@@ -48,6 +49,7 @@ import java.util.TimerTask;
 import java.util.concurrent.Executor;
 import java.util.logging.Logger;
 
+@Arrays
 public abstract class AbstractArraysTest<A> {
 
   private static final BaseConnection ENCODING_CONNECTION = new EncodingConnection(Encoding.getJVMEncoding("utf-8"));
@@ -1112,5 +1114,10 @@ public abstract class AbstractArraysTest<A> {
     public boolean getLogServerErrorDetail() {
       return false;
     }
+
+    @Override
+    public boolean getConvertBooleanToNumeric() {
+      return false;
+    }
   }
 }
