@@ -5,6 +5,12 @@
 
 package org.postgresql.test;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
+import static org.postgresql.util.internal.Nullness.castNonNull;
+
 import org.postgresql.PGConnection;
 import org.postgresql.PGProperty;
 import org.postgresql.core.BaseConnection;
@@ -15,14 +21,11 @@ import org.postgresql.jdbc.PgConnection;
 import org.postgresql.jdbc.ResourceLock;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.URLCoder;
+import org.postgresql.util.internal.FileUtils;
 
 // import org.checkerframework.checker.nullness.qual.Nullable;
-import org.junit.Assert;
-import org.junit.Assume;
 
-import java.io.Closeable;
 import java.io.File;
-import java.io.FileInputStream;
 import java.io.IOException;
 import java.sql.Connection;
 import java.sql.DriverManager;
@@ -81,7 +84,7 @@ public class TestUtil {
    * @return the test URL property value if it exists in the Properties object;
    *         otherwise, the default value of the specified property
    */
-  public static String getTestUrlProperty(Properties props, PGProperty property) {
+  public static /* @Nullable */ String getTestUrlProperty(Properties props, PGProperty property) {
     return props.getProperty(
         TEST_URL_PROPERTY_PREFIX + property.getName(), property.getDefaultValue());
   }
@@ -127,6 +130,9 @@ public class TestUtil {
         continue;
       }
       String value = props.getProperty(propertyName);
+      if (value == null) {
+        throw new IllegalArgumentException("Null value for property " + propertyName);
+      }
       String name = propertyName.substring(TEST_URL_PROPERTY_PREFIX.length());
       sb.append("&").append(URLCoder.encode(name)).append("=").append(URLCoder.encode(value));
     }
@@ -137,14 +143,15 @@ public class TestUtil {
    * Returns the Test server
    */
   public static String getServer() {
-    return getTestUrlProperty(System.getProperties(), PGProperty.PG_HOST);
+    return castNonNull(getTestUrlProperty(System.getProperties(), PGProperty.PG_HOST));
   }
 
   /*
    * Returns the Test port
    */
   public static int getPort() {
-    return Integer.parseInt(getTestUrlProperty(System.getProperties(), PGProperty.PG_PORT));
+    return Integer.parseInt(
+        castNonNull(getTestUrlProperty(System.getProperties(), PGProperty.PG_PORT)));
   }
 
   /*
@@ -162,7 +169,7 @@ public class TestUtil {
    * Returns the Test database
    */
   public static String getDatabase() {
-    return getTestUrlProperty(System.getProperties(), PGProperty.PG_DBNAME);
+    return castNonNull(getTestUrlProperty(System.getProperties(), PGProperty.PG_DBNAME));
   }
 
   /*
@@ -182,25 +189,25 @@ public class TestUtil {
   /*
    * Returns password for default callbackhandler
    */
-  public static String getSslPassword() {
+  public static /* @Nullable */ String getSslPassword() {
     return System.getProperty(PGProperty.SSL_PASSWORD.getName());
   }
 
   /*
    * Returns the user for SSPI authentication tests
    */
-  public static String getSSPIUser() {
+  public static /* @Nullable */ String getSSPIUser() {
     return System.getProperty("sspiusername");
   }
 
   /*
    * postgres like user
    */
-  public static String getPrivilegedUser() {
+  public static /* @Nullable */ String getPrivilegedUser() {
     return System.getProperty("privilegedUser");
   }
 
-  public static String getPrivilegedPassword() {
+  public static /* @Nullable */ String getPrivilegedPassword() {
     return System.getProperty("privilegedPassword");
   }
 
@@ -231,7 +238,7 @@ public class TestUtil {
           continue;
         }
         try {
-          p.load(new FileInputStream(f));
+          p.load(FileUtils.newBufferedInputStream(f));
         } catch (IOException ex) {
           // ignore
         }
@@ -240,7 +247,7 @@ public class TestUtil {
     return p;
   }
 
-  private static Properties sslTestProperties;
+  private static /* @Nullable */ Properties sslTestProperties;
 
   private static void initSslTestProperties() {
     try (ResourceLock ignore = lock.obtain()) {
@@ -250,17 +257,21 @@ public class TestUtil {
     }
   }
 
-  private static String getSslTestProperty(String name) {
+  private static /* @Nullable */ String getSslTestProperty(String name) {
     initSslTestProperties();
-    return sslTestProperties.getProperty(name);
+    return castNonNull(sslTestProperties).getProperty(name);
   }
 
   public static void assumeSslTestsEnabled() {
-    Assume.assumeTrue(Boolean.parseBoolean(getSslTestProperty("enable_ssl_tests")));
+    assumeTrue(Boolean.parseBoolean(getSslTestProperty("enable_ssl_tests")));
   }
 
   public static String getSslTestCertPath(String name) {
-    File certdir = TestUtil.getFile(getSslTestProperty("certdir"));
+    String certdirProp = getSslTestProperty("certdir");
+    if (certdirProp == null) {
+      throw new IllegalArgumentException("Missing property certdir in ssltest.properties");
+    }
+    File certdir = TestUtil.getFile(certdirProp);
     return new File(certdir, name).getAbsolutePath();
   }
 
@@ -376,7 +387,11 @@ public class TestUtil {
       // Copy all the properties from the given set and make system ones as a fallback
       propsWithDefaults = new Properties(systemProperties);
       for (String propertyName : propertyNames) {
-        propsWithDefaults.setProperty(propertyName, props.getProperty(propertyName));
+        String value = props.getProperty(propertyName);
+        if (value == null) {
+          throw new IllegalArgumentException("Property " + propertyName + " is null");
+        }
+        propsWithDefaults.setProperty(propertyName, value);
       }
     }
     return propsWithDefaults;
@@ -652,7 +667,7 @@ public class TestUtil {
       ps = con.prepareStatement("select count(*) from " + tableName + " as t");
       rs = ps.executeQuery();
       rs.next();
-      Assert.assertEquals(message, expectedRows, rs.getInt(1));
+      assertEquals(expectedRows, rs.getInt(1), message);
     } finally {
       closeQuietly(rs);
       closeQuietly(ps);
@@ -661,7 +676,7 @@ public class TestUtil {
 
   public static void assertTransactionState(String message, Connection con, TransactionState expected) {
     TransactionState actual = TestUtil.getTransactionState(con);
-    Assert.assertEquals(message, expected, actual);
+    assertEquals(expected, actual, message);
   }
 
   /*
@@ -671,7 +686,7 @@ public class TestUtil {
     return insertSQL(table, null, values);
   }
 
-  public static String insertSQL(String table, String columns, String values) {
+  public static String insertSQL(String table, /* @Nullable */ String columns, String values) {
     String s = "INSERT INTO " + table;
 
     if (columns != null) {
@@ -688,11 +703,11 @@ public class TestUtil {
     return selectSQL(table, columns, null, null);
   }
 
-  public static String selectSQL(String table, String columns, String where) {
+  public static String selectSQL(String table, String columns, /* @Nullable */ String where) {
     return selectSQL(table, columns, where, null);
   }
 
-  public static String selectSQL(String table, String columns, String where, String other) {
+  public static String selectSQL(String table, String columns, /* @Nullable */ String where, /* @Nullable */ String other) {
     String s = "SELECT " + columns + " FROM " + table;
 
     if (where != null) {
@@ -766,7 +781,7 @@ public class TestUtil {
   public static void assumeHaveMinimumServerVersion(Version version)
       throws SQLException {
     try (Connection conn = openPrivilegedDB()) {
-      Assume.assumeTrue(TestUtil.haveMinimumServerVersion(conn, version));
+      assumeTrue(TestUtil.haveMinimumServerVersion(conn, version));
     }
   }
 
@@ -842,38 +857,15 @@ public class TestUtil {
    * the caller to detect if the column lookup was successful.
    */
   public static int findColumn(PreparedStatement query, String label) throws SQLException {
-    int returnValue = 0;
-    ResultSet rs = query.executeQuery();
-    if (rs.next()) {
-      try {
-        returnValue = rs.findColumn(label);
-      } catch (SQLException sqle) {
-      } // consume exception to allow cleanup of resource.
-    }
-    rs.close();
-    return returnValue;
-  }
-
-  /**
-   * Close a resource and ignore any errors during closing.
-   */
-  public static void closeQuietly(/* @Nullable */ Closeable resource) {
-    if (resource != null) {
-      try {
-        resource.close();
-      } catch (Exception ignore) {
+    try (ResultSet rs = query.executeQuery()) {
+      if (!rs.next()) {
+        return 0;
       }
-    }
-  }
-
-  /**
-   * Close a Connection and ignore any errors during closing.
-   */
-  public static void closeQuietly(/* @Nullable */ Connection conn) {
-    if (conn != null) {
       try {
-        conn.close();
-      } catch (SQLException ignore) {
+        return rs.findColumn(label);
+      } catch (SQLException e) {
+        // Column was not found, return 0
+        return 0;
       }
     }
   }
@@ -886,6 +878,7 @@ public class TestUtil {
       try {
         stmt.close();
       } catch (SQLException ignore) {
+        // ignore
       }
     }
   }
@@ -898,6 +891,7 @@ public class TestUtil {
       try {
         rs.close();
       } catch (SQLException ignore) {
+        // ignore
       }
     }
   }
@@ -996,12 +990,12 @@ public class TestUtil {
    * Execute a SQL query with a given connection, fetch the first row, and return its
    * string value.
    */
-  public static String queryForString(Connection conn, String sql) throws SQLException {
+  public static /* @Nullable */ String queryForString(Connection conn, String sql) throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery(sql);
-    Assert.assertTrue("Query should have returned exactly one row but none was found: " + sql, rs.next());
+    assertTrue(rs.next(), () -> "Query should have returned exactly one row but none was found: " + sql);
     String value = rs.getString(1);
-    Assert.assertFalse("Query should have returned exactly one row but more than one found: " + sql, rs.next());
+    assertFalse(rs.next(), () -> "Query should have returned exactly one row but more than one found: " + sql);
     rs.close();
     stmt.close();
     return value;
@@ -1010,13 +1004,13 @@ public class TestUtil {
   /**
    * Same as queryForString(...) above but with a single string param.
    */
-  public static String queryForString(Connection conn, String sql, String param) throws SQLException {
+  public static /* @Nullable */ String queryForString(Connection conn, String sql, String param) throws SQLException {
     PreparedStatement stmt = conn.prepareStatement(sql);
     stmt.setString(1, param);
     ResultSet rs = stmt.executeQuery();
-    Assert.assertTrue("Query should have returned exactly one row but none was found: " + sql, rs.next());
+    assertTrue(rs.next(), () -> "Query should have returned exactly one row but none was found: " + sql);
     String value = rs.getString(1);
-    Assert.assertFalse("Query should have returned exactly one row but more than one found: " + sql, rs.next());
+    assertFalse(rs.next(), () -> "Query should have returned exactly one row but more than one found: " + sql);
     rs.close();
     stmt.close();
     return value;
@@ -1026,15 +1020,15 @@ public class TestUtil {
    * Execute a SQL query with a given connection, fetch the first row, and return its
    * boolean value.
    */
-  public static Boolean queryForBoolean(Connection conn, String sql) throws SQLException {
+  public static /* @Nullable */ Boolean queryForBoolean(Connection conn, String sql) throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery(sql);
-    Assert.assertTrue("Query should have returned exactly one row but none was found: " + sql, rs.next());
+    assertTrue(rs.next(), () -> "Query should have returned exactly one row but none was found: " + sql);
     Boolean value = rs.getBoolean(1);
     if (rs.wasNull()) {
       value = null;
     }
-    Assert.assertFalse("Query should have returned exactly one row but more than one found: " + sql, rs.next());
+    assertFalse(rs.next(), () -> "Query should have returned exactly one row but more than one found: " + sql);
     rs.close();
     stmt.close();
     return value;
@@ -1084,6 +1078,9 @@ public class TestUtil {
    */
   private static Connection createPrivilegedConnection(Connection conn) throws SQLException {
     String url = conn.getMetaData().getURL();
+    if (url == null) {
+      throw new IllegalStateException("conn.getMetaData().getURL() returned null, so can't reconstruct the URL");
+    }
     Properties props = new Properties(conn.getClientInfo());
     PGProperty.USER.set(props, getPrivilegedUser());
     PGProperty.PASSWORD.set(props, getPrivilegedPassword());
