@@ -5,20 +5,21 @@
 
 package org.postgresql.test.core;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import org.postgresql.core.JavaVersion;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
-public class JavaVersionTest {
+class JavaVersionTest {
   @Test
-  public void testGetRuntimeVersion() {
+  void getRuntimeVersion() {
     String currentVersion = System.getProperty("java.version");
     String msg = "java.version = " + currentVersion + ", JavaVersion.getRuntimeVersion() = "
         + JavaVersion.getRuntimeVersion();
     System.out.println(msg);
     if (currentVersion.startsWith("1.8")) {
-      Assert.assertEquals(msg, JavaVersion.v1_8, JavaVersion.getRuntimeVersion());
+      assertEquals(JavaVersion.v1_8, JavaVersion.getRuntimeVersion(), msg);
     }
   }
 }
