@@ -5,8 +5,11 @@
 
 package org.postgresql.test.jdbc2;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import org.postgresql.PGConnection;
 import org.postgresql.core.BaseConnection;
@@ -18,10 +21,9 @@ import org.postgresql.jdbc.PreferQueryMode;
 import org.postgresql.test.TestUtil;
 import org.postgresql.util.PSQLException;
 
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedClass;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.math.BigDecimal;
 import java.sql.Array;
@@ -37,7 +39,8 @@ import java.sql.Types;
 import java.util.ArrayList;
 import java.util.Collection;
 
-@RunWith(Parameterized.class)
+@ParameterizedClass
+@MethodSource("data")
 public class ArrayTest extends BaseTest4 {
   private Connection conn;
 
@@ -45,7 +48,6 @@ public class ArrayTest extends BaseTest4 {
     setBinaryMode(binaryMode);
   }
 
-  @Parameterized.Parameters(name = "binary = {0}")
   public static Iterable<Object[]> data() {
     Collection<Object[]> ids = new ArrayList<>();
     for (BinaryMode binaryMode : BinaryMode.values()) {
@@ -100,10 +102,10 @@ public class ArrayTest extends BaseTest4 {
 
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT intarr, decarr, strarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
-    Assert.assertEquals(Types.INTEGER, arr.getBaseType());
+    assertEquals(Types.INTEGER, arr.getBaseType());
     Integer[] intarr = (Integer[]) arr.getArray();
     assertEquals(3, intarr.length);
     assertEquals(1, intarr[0].intValue());
@@ -161,7 +163,7 @@ public class ArrayTest extends BaseTest4 {
 
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT intarr[1], decarr[1], strarr[1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -182,7 +184,7 @@ public class ArrayTest extends BaseTest4 {
 
     stmt = conn.createStatement();
     rs = stmt.executeQuery("SELECT intarr[1], decarr[1], strarr[1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -203,7 +205,7 @@ public class ArrayTest extends BaseTest4 {
 
     stmt = conn.createStatement();
     rs = stmt.executeQuery("SELECT intarr[1][1], decarr[1][1], strarr[1][1], intarr[2][1], decarr[2][1], strarr[2][1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -227,7 +229,7 @@ public class ArrayTest extends BaseTest4 {
 
     stmt = conn.createStatement();
     rs = stmt.executeQuery("SELECT intarr[1][1], decarr[1][1], strarr[1][1], intarr[2][1], decarr[2][1], strarr[2][1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -252,7 +254,7 @@ public class ArrayTest extends BaseTest4 {
 
     stmt = conn.createStatement();
     rs = stmt.executeQuery("SELECT intarr[1][1][1], decarr[1][1][1], strarr[1][1][1], intarr[2][1][1], decarr[2][1][1], strarr[2][1][1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -277,7 +279,7 @@ public class ArrayTest extends BaseTest4 {
 
     stmt = conn.createStatement();
     rs = stmt.executeQuery("SELECT intarr[1][1][1], decarr[1][1][1], strarr[1][1][1], intarr[2][1][1], decarr[2][1][1], strarr[2][1][1] FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     assertEquals(origIntArray[0][0][0], rs.getInt(1));
     assertEquals(origDblArray[0][0][0], rs.getDouble(2), 0.001);
@@ -304,29 +306,29 @@ public class ArrayTest extends BaseTest4 {
 
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT intarr, decarr, strarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
-    Assert.assertEquals(Types.INTEGER, arr.getBaseType());
+    assertEquals(Types.INTEGER, arr.getBaseType());
     Integer[] intarr = (Integer[]) arr.getArray();
-    Assert.assertEquals(3, intarr.length);
-    Assert.assertEquals(1, intarr[0].intValue());
-    Assert.assertEquals(2, intarr[1].intValue());
-    Assert.assertEquals(3, intarr[2].intValue());
+    assertEquals(3, intarr.length);
+    assertEquals(1, intarr[0].intValue());
+    assertEquals(2, intarr[1].intValue());
+    assertEquals(3, intarr[2].intValue());
 
     arr = rs.getArray(2);
-    Assert.assertEquals(Types.NUMERIC, arr.getBaseType());
+    assertEquals(Types.NUMERIC, arr.getBaseType());
     BigDecimal[] decarr = (BigDecimal[]) arr.getArray();
-    Assert.assertEquals(2, decarr.length);
-    Assert.assertEquals(new BigDecimal("3.1"), decarr[0]);
-    Assert.assertEquals(new BigDecimal("1.4"), decarr[1]);
+    assertEquals(2, decarr.length);
+    assertEquals(new BigDecimal("3.1"), decarr[0]);
+    assertEquals(new BigDecimal("1.4"), decarr[1]);
 
     arr = rs.getArray(3);
-    Assert.assertEquals(Types.VARCHAR, arr.getBaseType());
+    assertEquals(Types.VARCHAR, arr.getBaseType());
     String[] strarr = (String[]) arr.getArray(2, 2);
-    Assert.assertEquals(2, strarr.length);
-    Assert.assertEquals("f'a", strarr[0]);
-    Assert.assertEquals("fa\"b", strarr[1]);
+    assertEquals(2, strarr.length);
+    assertEquals("f'a", strarr[0]);
+    assertEquals("fa\"b", strarr[1]);
 
     try {
       arraySupport.createArrayOf("int4", 1);
@@ -383,50 +385,50 @@ public class ArrayTest extends BaseTest4 {
       ResultSet rs =
           stmt.executeQuery(
               "SELECT floats, reals, varchars, times, timestamps, timestampstz FROM ansiarraytest");
-      Assert.assertTrue(rs.next());
+      assertTrue(rs.next());
 
       Array arr = rs.getArray(1);
-      Assert.assertEquals(Types.DOUBLE, arr.getBaseType());
+      assertEquals(Types.DOUBLE, arr.getBaseType());
       Double[] doubles = (Double[]) arr.getArray();
-      Assert.assertEquals(2, doubles.length);
-      Assert.assertEquals(1d, doubles[0], 0);
-      Assert.assertEquals(4d, doubles[1], 0);
+      assertEquals(2, doubles.length);
+      assertEquals(1d, doubles[0], 0);
+      assertEquals(4d, doubles[1], 0);
 
       arr = rs.getArray(2);
-      Assert.assertEquals(Types.REAL, arr.getBaseType());
+      assertEquals(Types.REAL, arr.getBaseType());
       Float[] floats = (Float[]) arr.getArray();
-      Assert.assertEquals(2, floats.length);
-      Assert.assertEquals(0f, floats[0], 0);
-      Assert.assertEquals(3f, floats[1], 0);
+      assertEquals(2, floats.length);
+      assertEquals(0f, floats[0], 0);
+      assertEquals(3f, floats[1], 0);
 
       arr = rs.getArray(3);
-      Assert.assertEquals(Types.VARCHAR, arr.getBaseType());
+      assertEquals(Types.VARCHAR, arr.getBaseType());
       String[] strings = (String[]) arr.getArray();
-      Assert.assertEquals(3, strings.length);
-      Assert.assertEquals("abc", strings[0]);
-      Assert.assertEquals("f'a", strings[1]);
-      Assert.assertEquals("fa\"b", strings[2]);
+      assertEquals(3, strings.length);
+      assertEquals("abc", strings[0]);
+      assertEquals("f'a", strings[1]);
+      assertEquals("fa\"b", strings[2]);
 
       arr = rs.getArray(4);
-      Assert.assertEquals(Types.TIME, arr.getBaseType());
+      assertEquals(Types.TIME, arr.getBaseType());
       Time[] times = (Time[]) arr.getArray();
-      Assert.assertEquals(2, times.length);
-      Assert.assertEquals(Time.valueOf("12:34:56"), times[0]);
-      Assert.assertEquals(Time.valueOf("03:30:25"), times[1]);
+      assertEquals(2, times.length);
+      assertEquals(Time.valueOf("12:34:56"), times[0]);
+      assertEquals(Time.valueOf("03:30:25"), times[1]);
 
       arr = rs.getArray(5);
-      Assert.assertEquals(Types.TIMESTAMP, arr.getBaseType());
+      assertEquals(Types.TIMESTAMP, arr.getBaseType());
       Timestamp[] tzarr = (Timestamp[]) arr.getArray();
-      Assert.assertEquals(2, times.length);
-      Assert.assertEquals(Timestamp.valueOf("2023-09-05 16:21:50"), tzarr[0]);
-      Assert.assertEquals(Timestamp.valueOf("2012-01-01 13:02:03"), tzarr[1]);
+      assertEquals(2, times.length);
+      assertEquals(Timestamp.valueOf("2023-09-05 16:21:50"), tzarr[0]);
+      assertEquals(Timestamp.valueOf("2012-01-01 13:02:03"), tzarr[1]);
 
       arr = rs.getArray(6);
-      Assert.assertEquals(Types.TIMESTAMP, arr.getBaseType());
+      assertEquals(Types.TIMESTAMP, arr.getBaseType());
       tzarr = (Timestamp[]) arr.getArray();
-      Assert.assertEquals(2, times.length);
-      Assert.assertEquals(822427200000L, tzarr[0].getTime());
-      Assert.assertEquals(871764660000L, tzarr[1].getTime());
+      assertEquals(2, times.length);
+      assertEquals(822427200000L, tzarr[0].getTime());
+      assertEquals(871764660000L, tzarr[1].getTime());
 
       rs.close();
     } finally {
@@ -449,16 +451,16 @@ public class ArrayTest extends BaseTest4 {
 
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT intarr, decarr, strarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
-    Assert.assertNull(arr);
+    assertNull(arr);
 
     arr = rs.getArray(2);
-    Assert.assertNull(arr);
+    assertNull(arr);
 
     arr = rs.getArray(3);
-    Assert.assertNull(arr);
+    assertNull(arr);
 
     rs.close();
   }
@@ -472,29 +474,29 @@ public class ArrayTest extends BaseTest4 {
         + TestUtil.escapeString(conn, "{abc,f'a,\"fa\\\"b\",def, un  quot\u000B \u2001 \r}") + "')");
 
     ResultSet rs = stmt.executeQuery("SELECT intarr, decarr, strarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
-    Assert.assertEquals(Types.INTEGER, arr.getBaseType());
+    assertEquals(Types.INTEGER, arr.getBaseType());
     Integer[] intarr = (Integer[]) arr.getArray();
-    Assert.assertEquals(3, intarr.length);
-    Assert.assertEquals(1, intarr[0].intValue());
-    Assert.assertEquals(2, intarr[1].intValue());
-    Assert.assertEquals(3, intarr[2].intValue());
+    assertEquals(3, intarr.length);
+    assertEquals(1, intarr[0].intValue());
+    assertEquals(2, intarr[1].intValue());
+    assertEquals(3, intarr[2].intValue());
 
     arr = rs.getArray(2);
-    Assert.assertEquals(Types.NUMERIC, arr.getBaseType());
+    assertEquals(Types.NUMERIC, arr.getBaseType());
     BigDecimal[] decarr = (BigDecimal[]) arr.getArray();
-    Assert.assertEquals(2, decarr.length);
-    Assert.assertEquals(new BigDecimal("3.1"), decarr[0]);
-    Assert.assertEquals(new BigDecimal("1.4"), decarr[1]);
+    assertEquals(2, decarr.length);
+    assertEquals(new BigDecimal("3.1"), decarr[0]);
+    assertEquals(new BigDecimal("1.4"), decarr[1]);
 
     arr = rs.getArray(3);
-    Assert.assertEquals(Types.VARCHAR, arr.getBaseType());
+    assertEquals(Types.VARCHAR, arr.getBaseType());
     String[] strarr = (String[]) arr.getArray(2, 2);
-    Assert.assertEquals(2, strarr.length);
-    Assert.assertEquals("f'a", strarr[0]);
-    Assert.assertEquals("fa\"b", strarr[1]);
+    assertEquals(2, strarr.length);
+    assertEquals("f'a", strarr[0]);
+    assertEquals("fa\"b", strarr[1]);
 
     strarr = (String[]) arr.getArray();
     assertEquals(5, strarr.length);
@@ -514,53 +516,169 @@ public class ArrayTest extends BaseTest4 {
         + TestUtil.escapeString(conn, "{\"a\u2001b\",f'a,\"fa\\\"b\",def}") + "')");
 
     ResultSet rs = stmt.executeQuery("SELECT intarr, decarr, strarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
-    Assert.assertEquals(Types.INTEGER, arr.getBaseType());
+    assertEquals(Types.INTEGER, arr.getBaseType());
     ResultSet arrrs = arr.getResultSet();
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(1, arrrs.getInt(1));
-    Assert.assertEquals(1, arrrs.getInt(2));
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(2, arrrs.getInt(1));
-    Assert.assertEquals(2, arrrs.getInt(2));
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(3, arrrs.getInt(1));
-    Assert.assertEquals(3, arrrs.getInt(2));
-    Assert.assertTrue(!arrrs.next());
-    Assert.assertTrue(arrrs.previous());
-    Assert.assertEquals(3, arrrs.getInt(2));
+    assertTrue(arrrs.next());
+    assertEquals(1, arrrs.getInt(1));
+    assertEquals(1, arrrs.getInt(2));
+    assertTrue(arrrs.next());
+    assertEquals(2, arrrs.getInt(1));
+    assertEquals(2, arrrs.getInt(2));
+    assertTrue(arrrs.next());
+    assertEquals(3, arrrs.getInt(1));
+    assertEquals(3, arrrs.getInt(2));
+    assertFalse(arrrs.next());
+    assertTrue(arrrs.previous());
+    assertEquals(3, arrrs.getInt(2));
     arrrs.first();
-    Assert.assertEquals(1, arrrs.getInt(2));
+    assertEquals(1, arrrs.getInt(2));
     arrrs.close();
 
     arr = rs.getArray(2);
-    Assert.assertEquals(Types.NUMERIC, arr.getBaseType());
+    assertEquals(Types.NUMERIC, arr.getBaseType());
     arrrs = arr.getResultSet();
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(new BigDecimal("3.1"), arrrs.getBigDecimal(2));
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(new BigDecimal("1.4"), arrrs.getBigDecimal(2));
+    assertTrue(arrrs.next());
+    assertEquals(new BigDecimal("3.1"), arrrs.getBigDecimal(2));
+    assertTrue(arrrs.next());
+    assertEquals(new BigDecimal("1.4"), arrrs.getBigDecimal(2));
     arrrs.close();
 
     arr = rs.getArray(3);
-    Assert.assertEquals(Types.VARCHAR, arr.getBaseType());
+    assertEquals(Types.VARCHAR, arr.getBaseType());
     arrrs = arr.getResultSet(2, 2);
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(2, arrrs.getInt(1));
-    Assert.assertEquals("f'a", arrrs.getString(2));
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(3, arrrs.getInt(1));
-    Assert.assertEquals("fa\"b", arrrs.getString(2));
-    Assert.assertTrue(!arrrs.next());
+    assertTrue(arrrs.next());
+    assertEquals(2, arrrs.getInt(1));
+    assertEquals("f'a", arrrs.getString(2));
+    assertTrue(arrrs.next());
+    assertEquals(3, arrrs.getInt(1));
+    assertEquals("fa\"b", arrrs.getString(2));
+    assertFalse(arrrs.next());
     arrrs.close();
 
     arrrs = arr.getResultSet(1, 1);
-    Assert.assertTrue(arrrs.next());
-    Assert.assertEquals(1, arrrs.getInt(1));
-    Assert.assertEquals(stringWithNonAsciiWhiteSpace, arrrs.getString(2));
-    Assert.assertFalse(arrrs.next());
+    assertTrue(arrrs.next());
+    assertEquals(1, arrrs.getInt(1));
+    assertEquals(stringWithNonAsciiWhiteSpace, arrrs.getString(2));
+    assertFalse(arrrs.next());
+    arrrs.close();
+
+    rs.close();
+    stmt.close();
+  }
+
+  @Test
+  public void testMultiDimensionalArrayRetrieveResultSets() throws SQLException {
+    final int[][][] origIntArray = new int[3][2][1];
+    int i = 0;
+    for (int x = 0; x < 3; x++) {
+      for (int y = 0; y < 2; y++) {
+        for (int z = 0; z < 1; z++) {
+          origIntArray[x][y][z] = i;
+          i++;
+        }
+      }
+    }
+
+    PreparedStatement pstmt = conn.prepareStatement("INSERT INTO arrtest(intarr) VALUES (?)");
+    pstmt.setObject(1, origIntArray, Types.ARRAY);
+    pstmt.executeUpdate();
+    pstmt.close();
+
+    Statement stmt = conn.createStatement();
+    ResultSet rs = stmt.executeQuery("SELECT intarr FROM arrtest");
+    assertTrue(rs.next());
+
+    // {{{0},{1}},{{2},{3}},{{4},{5}}}
+    Array arr = rs.getArray(1);
+    assertEquals(Types.INTEGER, arr.getBaseType());
+    ResultSet arrrs = arr.getResultSet();
+    assertTrue(arrrs.next());
+    // {{0},{1}}
+    assertEquals(1, arrrs.getInt(1));
+    Array arr1 =  arrrs.getArray(2);
+    ResultSet arr1rs = arr1.getResultSet();
+    assertTrue(arr1rs.next());
+    // {0}
+    assertEquals(1, arr1rs.getInt(1));
+    Array arr11 =  arr1rs.getArray(2);
+    ResultSet arr11rs = arr11.getResultSet();
+    assertTrue(arr11rs.next());
+    assertEquals(1, arr11rs.getInt(1));
+    assertEquals(0, arr11rs.getInt(2));
+    assertFalse(arr11rs.next());
+    arr11rs.close();
+    assertTrue(arr1rs.next());
+    // {1}
+    assertEquals(2, arr1rs.getInt(1));
+    Array arr12 =  arr1rs.getArray(2);
+    ResultSet arr12rs = arr12.getResultSet();
+    assertTrue(arr12rs.next());
+    assertEquals(1, arr12rs.getInt(1));
+    assertEquals(1, arr12rs.getInt(2));
+    assertFalse(arr12rs.next());
+    arr12rs.close();
+    assertFalse(arr1rs.next());
+    arr1rs.close();
+    assertTrue(arrrs.next());
+
+    // {{2},{3}}
+    assertEquals(2, arrrs.getInt(1));
+    Array arr2 =  arrrs.getArray(2);
+    ResultSet arr2rs = arr2.getResultSet();
+    assertTrue(arr2rs.next());
+    // {2}
+    assertEquals(1, arr2rs.getInt(1));
+    Array arr21 =  arr2rs.getArray(2);
+    ResultSet arr21rs = arr21.getResultSet();
+    assertTrue(arr21rs.next());
+    assertEquals(1, arr21rs.getInt(1));
+    assertEquals(2, arr21rs.getInt(2));
+    assertFalse(arr21rs.next());
+    arr21rs.close();
+    assertTrue(arr2rs.next());
+    // {3}
+    assertEquals(2, arr2rs.getInt(1));
+    Array arr22 =  arr2rs.getArray(2);
+    ResultSet arr22rs = arr22.getResultSet();
+    assertTrue(arr22rs.next());
+    assertEquals(1, arr22rs.getInt(1));
+    assertEquals(3, arr22rs.getInt(2));
+    assertFalse(arr22rs.next());
+    arr22rs.close();
+    assertFalse(arr2rs.next());
+    arr2rs.close();
+    assertTrue(arrrs.next());
+
+    // {{4},{5}}
+    assertEquals(3, arrrs.getInt(1));
+    Array arr3 =  arrrs.getArray(2);
+    ResultSet arr3rs = arr3.getResultSet();
+    assertTrue(arr3rs.next());
+    // {4}
+    assertEquals(1, arr3rs.getInt(1));
+    Array arr31 =  arr3rs.getArray(2);
+    ResultSet arr31rs = arr31.getResultSet();
+    assertTrue(arr31rs.next());
+    assertEquals(1, arr31rs.getInt(1));
+    assertEquals(4, arr31rs.getInt(2));
+    assertFalse(arr31rs.next());
+    arr31rs.close();
+    assertTrue(arr3rs.next());
+    // {5}
+    assertEquals(2, arr3rs.getInt(1));
+    Array arr32 =  arr3rs.getArray(2);
+    ResultSet arr32rs = arr32.getResultSet();
+    assertTrue(arr32rs.next());
+    assertEquals(1, arr32rs.getInt(1));
+    assertEquals(5, arr32rs.getInt(2));
+    assertFalse(arr32rs.next());
+    arr32rs.close();
+    assertFalse(arr3rs.next());
+    arr3rs.close();
+    assertFalse(arrrs.next());
     arrrs.close();
 
     rs.close();
@@ -571,7 +689,7 @@ public class ArrayTest extends BaseTest4 {
   public void testSetArray() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet arrRS = stmt.executeQuery("SELECT '{1,2,3}'::int4[]");
-    Assert.assertTrue(arrRS.next());
+    assertTrue(arrRS.next());
     Array arr = arrRS.getArray(1);
     arrRS.close();
     stmt.close();
@@ -594,16 +712,16 @@ public class ArrayTest extends BaseTest4 {
     while (rs.next()) {
       resultCount++;
       Array result = rs.getArray(1);
-      Assert.assertEquals(Types.INTEGER, result.getBaseType());
-      Assert.assertEquals("int4", result.getBaseTypeName());
+      assertEquals(Types.INTEGER, result.getBaseType());
+      assertEquals("int4", result.getBaseTypeName());
 
       Integer[] intarr = (Integer[]) result.getArray();
-      Assert.assertEquals(3, intarr.length);
-      Assert.assertEquals(1, intarr[0].intValue());
-      Assert.assertEquals(2, intarr[1].intValue());
-      Assert.assertEquals(3, intarr[2].intValue());
+      assertEquals(3, intarr.length);
+      assertEquals(1, intarr[0].intValue());
+      assertEquals(2, intarr[1].intValue());
+      assertEquals(3, intarr[2].intValue());
     }
-    Assert.assertEquals(3, resultCount);
+    assertEquals(3, resultCount);
   }
 
   /**
@@ -617,12 +735,12 @@ public class ArrayTest extends BaseTest4 {
     stmt.executeUpdate("INSERT INTO arrtest (intarr) VALUES ('{1,2,3}')");
     stmt.executeUpdate("UPDATE arrtest SET intarr[0] = 0");
     ResultSet rs = stmt.executeQuery("SELECT intarr FROM arrtest");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array result = rs.getArray(1);
     Integer[] intarr = (Integer[]) result.getArray();
-    Assert.assertEquals(4, intarr.length);
+    assertEquals(4, intarr.length);
     for (int i = 0; i < intarr.length; i++) {
-      Assert.assertEquals(i, intarr[i].intValue());
+      assertEquals(i, intarr[i].intValue());
     }
   }
 
@@ -630,18 +748,18 @@ public class ArrayTest extends BaseTest4 {
   public void testMultiDimensionalArray() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT '{{1,2},{3,4}}'::int[]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
     Object[] oa = (Object[]) arr.getArray();
-    Assert.assertEquals(2, oa.length);
+    assertEquals(2, oa.length);
     Integer[] i0 = (Integer[]) oa[0];
-    Assert.assertEquals(2, i0.length);
-    Assert.assertEquals(1, i0[0].intValue());
-    Assert.assertEquals(2, i0[1].intValue());
+    assertEquals(2, i0.length);
+    assertEquals(1, i0[0].intValue());
+    assertEquals(2, i0[1].intValue());
     Integer[] i1 = (Integer[]) oa[1];
-    Assert.assertEquals(2, i1.length);
-    Assert.assertEquals(3, i1[0].intValue());
-    Assert.assertEquals(4, i1[1].intValue());
+    assertEquals(2, i1.length);
+    assertEquals(3, i1[0].intValue());
+    assertEquals(4, i1[1].intValue());
     rs.close();
     stmt.close();
   }
@@ -650,19 +768,19 @@ public class ArrayTest extends BaseTest4 {
   public void testNullValues() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT ARRAY[1,NULL,3]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
     Integer[] i = (Integer[]) arr.getArray();
-    Assert.assertEquals(3, i.length);
-    Assert.assertEquals(1, i[0].intValue());
-    Assert.assertNull(i[1]);
-    Assert.assertEquals(3, i[2].intValue());
+    assertEquals(3, i.length);
+    assertEquals(1, i[0].intValue());
+    assertNull(i[1]);
+    assertEquals(3, i[2].intValue());
   }
 
   @Test
   public void testNullFieldString() throws SQLException {
     Array arr = new PgArray((BaseConnection) conn, 1, (String) null);
-    Assert.assertNull(arr.toString());
+    assertNull(arr.toString());
   }
 
   @Test
@@ -690,10 +808,10 @@ public class ArrayTest extends BaseTest4 {
       stmt.executeUpdate("INSERT INTO arrtest VALUES (NULL, NULL, '" + TestUtil.escapeString(conn, stringArray) + "')");
 
       final ResultSet rs = stmt.executeQuery("SELECT strarr FROM arrtest");
-      Assert.assertTrue(rs.next());
+      assertTrue(rs.next());
 
       Array arr = rs.getArray(1);
-      Assert.assertEquals(Types.VARCHAR, arr.getBaseType());
+      assertEquals(Types.VARCHAR, arr.getBaseType());
       String[] strarr = (String[]) arr.getArray();
       assertEquals(5, strarr.length);
       assertEquals("f'a", strarr[0]);
@@ -728,54 +846,54 @@ public class ArrayTest extends BaseTest4 {
     ResultSet rs =
         stmt.executeQuery("SELECT relacl FROM pg_class WHERE relacl IS NOT NULL LIMIT 1");
     ResultSetMetaData rsmd = rs.getMetaData();
-    Assert.assertEquals(Types.ARRAY, rsmd.getColumnType(1));
+    assertEquals(Types.ARRAY, rsmd.getColumnType(1));
 
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
-    Assert.assertEquals("aclitem", arr.getBaseTypeName());
+    assertEquals("aclitem", arr.getBaseTypeName());
 
     ResultSet arrRS = arr.getResultSet();
     ResultSetMetaData arrRSMD = arrRS.getMetaData();
-    Assert.assertEquals("aclitem", arrRSMD.getColumnTypeName(2));
+    assertEquals("aclitem", arrRSMD.getColumnTypeName(2));
   }
 
   @Test
   public void testRecursiveResultSets() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT '{{1,2},{3,4}}'::int[]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
 
     ResultSet arrRS = arr.getResultSet();
     ResultSetMetaData arrRSMD = arrRS.getMetaData();
-    Assert.assertEquals(Types.ARRAY, arrRSMD.getColumnType(2));
-    Assert.assertEquals("_int4", arrRSMD.getColumnTypeName(2));
+    assertEquals(Types.ARRAY, arrRSMD.getColumnType(2));
+    assertEquals("_int4", arrRSMD.getColumnTypeName(2));
 
-    Assert.assertTrue(arrRS.next());
-    Assert.assertEquals(1, arrRS.getInt(1));
+    assertTrue(arrRS.next());
+    assertEquals(1, arrRS.getInt(1));
     Array a1 = arrRS.getArray(2);
     ResultSet a1RS = a1.getResultSet();
     ResultSetMetaData a1RSMD = a1RS.getMetaData();
-    Assert.assertEquals(Types.INTEGER, a1RSMD.getColumnType(2));
-    Assert.assertEquals("int4", a1RSMD.getColumnTypeName(2));
+    assertEquals(Types.INTEGER, a1RSMD.getColumnType(2));
+    assertEquals("int4", a1RSMD.getColumnTypeName(2));
 
-    Assert.assertTrue(a1RS.next());
-    Assert.assertEquals(1, a1RS.getInt(2));
-    Assert.assertTrue(a1RS.next());
-    Assert.assertEquals(2, a1RS.getInt(2));
-    Assert.assertTrue(!a1RS.next());
+    assertTrue(a1RS.next());
+    assertEquals(1, a1RS.getInt(2));
+    assertTrue(a1RS.next());
+    assertEquals(2, a1RS.getInt(2));
+    assertFalse(a1RS.next());
     a1RS.close();
 
-    Assert.assertTrue(arrRS.next());
-    Assert.assertEquals(2, arrRS.getInt(1));
+    assertTrue(arrRS.next());
+    assertEquals(2, arrRS.getInt(1));
     Array a2 = arrRS.getArray(2);
     ResultSet a2RS = a2.getResultSet();
 
-    Assert.assertTrue(a2RS.next());
-    Assert.assertEquals(3, a2RS.getInt(2));
-    Assert.assertTrue(a2RS.next());
-    Assert.assertEquals(4, a2RS.getInt(2));
-    Assert.assertTrue(!a2RS.next());
+    assertTrue(a2RS.next());
+    assertEquals(3, a2RS.getInt(2));
+    assertTrue(a2RS.next());
+    assertEquals(4, a2RS.getInt(2));
+    assertFalse(a2RS.next());
     a2RS.close();
 
     arrRS.close();
@@ -787,13 +905,13 @@ public class ArrayTest extends BaseTest4 {
   public void testNullString() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT '{a,NULL}'::text[]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
 
     String[] s = (String[]) arr.getArray();
-    Assert.assertEquals(2, s.length);
-    Assert.assertEquals("a", s[0]);
-    Assert.assertNull(s[1]);
+    assertEquals(2, s.length);
+    assertEquals("a", s[0]);
+    assertNull(s[1]);
   }
 
   @Test
@@ -805,41 +923,41 @@ public class ArrayTest extends BaseTest4 {
     sql += "'{{c\\\\\"d, ''}, {\"\\\\\\\\\",\"''\"}}'::text[]";
 
     ResultSet rs = stmt.executeQuery(sql);
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
 
     Array arr = rs.getArray(1);
     String[][] s = (String[][]) arr.getArray();
-    Assert.assertEquals("c\"d", s[0][0]);
-    Assert.assertEquals("'", s[0][1]);
-    Assert.assertEquals("\\", s[1][0]);
-    Assert.assertEquals("'", s[1][1]);
+    assertEquals("c\"d", s[0][0]);
+    assertEquals("'", s[0][1]);
+    assertEquals("\\", s[1][0]);
+    assertEquals("'", s[1][1]);
 
     ResultSet arrRS = arr.getResultSet();
 
-    Assert.assertTrue(arrRS.next());
+    assertTrue(arrRS.next());
     Array a1 = arrRS.getArray(2);
     ResultSet rs1 = a1.getResultSet();
-    Assert.assertTrue(rs1.next());
-    Assert.assertEquals("c\"d", rs1.getString(2));
-    Assert.assertTrue(rs1.next());
-    Assert.assertEquals("'", rs1.getString(2));
-    Assert.assertTrue(!rs1.next());
+    assertTrue(rs1.next());
+    assertEquals("c\"d", rs1.getString(2));
+    assertTrue(rs1.next());
+    assertEquals("'", rs1.getString(2));
+    assertFalse(rs1.next());
 
-    Assert.assertTrue(arrRS.next());
+    assertTrue(arrRS.next());
     Array a2 = arrRS.getArray(2);
     ResultSet rs2 = a2.getResultSet();
-    Assert.assertTrue(rs2.next());
-    Assert.assertEquals("\\", rs2.getString(2));
-    Assert.assertTrue(rs2.next());
-    Assert.assertEquals("'", rs2.getString(2));
-    Assert.assertTrue(!rs2.next());
+    assertTrue(rs2.next());
+    assertEquals("\\", rs2.getString(2));
+    assertTrue(rs2.next());
+    assertEquals("'", rs2.getString(2));
+    assertFalse(rs2.next());
   }
 
   @Test
   public void testWriteMultiDimensional() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT '{{1,2},{3,4}}'::int[]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
     rs.close();
     stmt.close();
@@ -851,14 +969,14 @@ public class ArrayTest extends BaseTest4 {
     PreparedStatement pstmt = conn.prepareStatement(sql);
     pstmt.setArray(1, arr);
     rs = pstmt.executeQuery();
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     arr = rs.getArray(1);
 
     Integer[][] i = (Integer[][]) arr.getArray();
-    Assert.assertEquals(1, i[0][0].intValue());
-    Assert.assertEquals(2, i[0][1].intValue());
-    Assert.assertEquals(3, i[1][0].intValue());
-    Assert.assertEquals(4, i[1][1].intValue());
+    assertEquals(1, i[0][0].intValue());
+    assertEquals(2, i[0][1].intValue());
+    assertEquals(3, i[1][0].intValue());
+    assertEquals(4, i[1][1].intValue());
   }
 
   /*
@@ -869,24 +987,24 @@ public class ArrayTest extends BaseTest4 {
   public void testNonStandardDelimiter() throws SQLException {
     Statement stmt = conn.createStatement();
     ResultSet rs = stmt.executeQuery("SELECT '{(3,4),(1,2);(7,8),(5,6)}'::box[]");
-    Assert.assertTrue(rs.next());
+    assertTrue(rs.next());
     Array arr = rs.getArray(1);
 
     ResultSet arrRS = arr.getResultSet();
 
-    Assert.assertTrue(arrRS.next());
+    assertTrue(arrRS.next());
     PGbox box1 = (PGbox) arrRS.getObject(2);
     PGpoint p1 = box1.point[0];
-    Assert.assertEquals(3, p1.x, 0.001);
-    Assert.assertEquals(4, p1.y, 0.001);
+    assertEquals(3, p1.x, 0.001);
+    assertEquals(4, p1.y, 0.001);
 
-    Assert.assertTrue(arrRS.next());
+    assertTrue(arrRS.next());
     PGbox box2 = (PGbox) arrRS.getObject(2);
     PGpoint p2 = box2.point[1];
-    Assert.assertEquals(5, p2.x, 0.001);
-    Assert.assertEquals(6, p2.y, 0.001);
+    assertEquals(5, p2.x, 0.001);
+    assertEquals(6, p2.y, 0.001);
 
-    Assert.assertTrue(!arrRS.next());
+    assertFalse(arrRS.next());
   }
 
   @Test
@@ -898,8 +1016,10 @@ public class ArrayTest extends BaseTest4 {
       Array array = rs.getArray(1);
       if (!rs.wasNull()) {
         ResultSet ars = array.getResultSet();
-        Assert.assertEquals("get columntype should return Types.INTEGER", java.sql.Types.INTEGER,
-            ars.getMetaData().getColumnType(1));
+        assertEquals(
+            Types.INTEGER,
+            ars.getMetaData().getColumnType(1),
+            "get columntype should return Types.INTEGER");
       }
     }
   }
