@@ -111,6 +111,22 @@ class IntervalTest {
     assertEquals("1 years 3 mons 0 days 0 hours 0 mins 0.0 secs", coercedStringValue);
   }
 
+  @Test
+  void checkCapitalization() throws Exception {
+    PGInterval pgi = new PGInterval("1 year 3 months 4 days 5 hours 6 minutes");
+    PGInterval yCapital = new PGInterval("1 Year 3 months 4 days 5 hours 6 minutes");
+    PGInterval mCapital = new PGInterval("1 year 3 Months 4 days 5 hours 6 minutes");
+    PGInterval dCapital = new PGInterval("1 year 3 months 4 Days 5 hours 6 minutes");
+    PGInterval hCapital = new PGInterval("1 year 3 months 4 days 5 Hours 6 minutes");
+    PGInterval minCapital = new PGInterval("1 year 3 months 4 days 5 hours 6 Minutes");
+
+    assertEquals(pgi, yCapital);
+    assertEquals(pgi, mCapital);
+    assertEquals(pgi, dCapital);
+    assertEquals(pgi, hCapital);
+    assertEquals(pgi, minCapital);
+  }
+
   @Test
   void daysHours() throws SQLException {
     Statement stmt = conn.createStatement();
@@ -186,7 +202,7 @@ class IntervalTest {
     assertEquals(0, pgi.getSeconds(), 0);
   }
 
-  private Calendar getStartCalendar() {
+  private static Calendar getStartCalendar() {
     Calendar cal = new GregorianCalendar();
     cal.set(Calendar.YEAR, 2005);
     cal.set(Calendar.MONTH, 4);
@@ -375,7 +391,7 @@ class IntervalTest {
     assertEquals(1, pgi.getMicroSeconds());
   }
 
-  private java.sql.Date makeDate(int y, int m, int d) {
+  private static java.sql.Date makeDate(int y, int m, int d) {
     return new java.sql.Date(y - 1900, m - 1, d);
   }
 }
