@@ -8,17 +8,18 @@ package org.postgresql.test.jdbc4.jdbc41;
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.core.IsEqual.equalTo;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import org.postgresql.PGProperty;
 import org.postgresql.test.TestUtil;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.sql.Connection;
 import java.sql.PreparedStatement;
@@ -29,12 +30,12 @@ import java.sql.Statement;
 import java.sql.Types;
 import java.util.Properties;
 
-public class SchemaTest {
+class SchemaTest {
   private Connection conn;
   private boolean dropUserSchema;
 
-  @Before
-  public void setUp() throws Exception {
+  @BeforeEach
+  void setUp() throws Exception {
     conn = TestUtil.openDB();
     Statement stmt = conn.createStatement();
     try {
@@ -57,8 +58,8 @@ public class SchemaTest {
     TestUtil.createTable(conn, "schema2.sptest", "id varchar");
   }
 
-  @After
-  public void tearDown() throws SQLException {
+  @AfterEach
+  void tearDown() throws SQLException {
     conn.setAutoCommit(true);
     conn.setSchema(null);
     Statement stmt = conn.createStatement();
@@ -79,7 +80,7 @@ public class SchemaTest {
    * Test that what you set is what you get.
    */
   @Test
-  public void testGetSetSchema() throws SQLException {
+  void getSetSchema() throws SQLException {
     conn.setSchema("schema1");
     assertEquals("schema1", conn.getSchema());
     conn.setSchema("schema2");
@@ -99,10 +100,10 @@ public class SchemaTest {
    * objects from other schemas but doesn't prevent to prefix-access to them.
    */
   @Test
-  public void testUsingSchema() throws SQLException {
+  void usingSchema() throws SQLException {
     Statement stmt = conn.createStatement();
     try {
-      try {
+      assertDoesNotThrow(() -> {
         conn.setSchema("schema1");
         stmt.executeQuery(TestUtil.selectSQL("table1", "*"));
         stmt.executeQuery(TestUtil.selectSQL("schema2.table2", "*"));
@@ -132,9 +133,7 @@ public class SchemaTest {
         } catch (SQLException e) {
           // expected
         }
-      } catch (SQLException e) {
-        fail("Could not find expected schema elements: " + e.getMessage());
-      }
+      }, "Could not find expected schema elements: ");
     } finally {
       try {
         stmt.close();
@@ -147,7 +146,7 @@ public class SchemaTest {
    * Test that get schema returns the schema with the highest priority in the search path.
    */
   @Test
-  public void testMultipleSearchPath() throws SQLException {
+  void multipleSearchPath() throws SQLException {
     execute("SET search_path TO schema1,schema2");
     assertEquals("schema1", conn.getSchema());
 
@@ -156,7 +155,7 @@ public class SchemaTest {
   }
 
   @Test
-  public void testSchemaInProperties() throws Exception {
+  void schemaInProperties() throws Exception {
     Properties properties = new Properties();
     properties.setProperty("currentSchema", "schema1");
     Connection conn = TestUtil.openDB(properties);
@@ -178,7 +177,7 @@ public class SchemaTest {
   }
 
   @Test
-  public void testSchemaPath$User() throws Exception {
+  public void schemaPath$User() throws Exception {
     execute("SET search_path TO \"$user\",public,schema2");
     assertEquals(TestUtil.getUser(), conn.getSchema());
   }
@@ -196,18 +195,18 @@ public class SchemaTest {
   }
 
   @Test
-  public void testSearchPathPreparedStatementAutoCommitFalse() throws SQLException {
+  void searchPathPreparedStatementAutoCommitFalse() throws SQLException {
     conn.setAutoCommit(false);
-    testSearchPathPreparedStatement();
+    searchPathPreparedStatementAutoCommitTrue();
   }
 
   @Test
-  public void testSearchPathPreparedStatementAutoCommitTrue() throws SQLException {
-    testSearchPathPreparedStatement();
+  void searchPathPreparedStatementAutoCommitTrue() throws SQLException {
+    searchPathPreparedStatement();
   }
 
   @Test
-  public void testSearchPathPreparedStatement() throws SQLException {
+  void searchPathPreparedStatement() throws SQLException {
     execute("set search_path to schema1,public");
     PreparedStatement ps = conn.prepareStatement("select * from sptest");
     for (int i = 0; i < 10; i++) {
@@ -224,7 +223,7 @@ public class SchemaTest {
   }
 
   @Test
-  public void testCurrentSchemaPropertyVisibilityTableDuringFunctionCreation() throws SQLException {
+  void currentSchemaPropertyVisibilityTableDuringFunctionCreation() throws SQLException {
     Properties properties = new Properties();
     properties.setProperty(PGProperty.CURRENT_SCHEMA.getName(), "public,schema1,schema2");
     Connection connection = TestUtil.openDB(properties);
@@ -238,7 +237,7 @@ public class SchemaTest {
   }
 
   @Test
-  public void testCurrentSchemaPropertyNotVisibilityTableDuringFunctionCreation() throws SQLException {
+  void currentSchemaPropertyNotVisibilityTableDuringFunctionCreation() throws SQLException {
     Properties properties = new Properties();
     properties.setProperty(PGProperty.CURRENT_SCHEMA.getName(), "public,schema2");
 
@@ -270,8 +269,8 @@ public class SchemaTest {
   }
 
   @Test
-  public void testCurrentSchemaPropertyVisibilityFunction() throws SQLException {
-    testCurrentSchemaPropertyVisibilityTableDuringFunctionCreation();
+  void currentSchemaPropertyVisibilityFunction() throws SQLException {
+    currentSchemaPropertyVisibilityTableDuringFunctionCreation();
     Properties properties = new Properties();
     properties.setProperty(PGProperty.CURRENT_SCHEMA.getName(), "public,schema1,schema2");
     Connection connection = TestUtil.openDB(properties);
@@ -281,8 +280,8 @@ public class SchemaTest {
   }
 
   @Test
-  public void testCurrentSchemaPropertyNotVisibilityTableInsideFunction() throws SQLException {
-    testCurrentSchemaPropertyVisibilityTableDuringFunctionCreation();
+  void currentSchemaPropertyNotVisibilityTableInsideFunction() throws SQLException {
+    currentSchemaPropertyVisibilityTableDuringFunctionCreation();
     Properties properties = new Properties();
     properties.setProperty(PGProperty.CURRENT_SCHEMA.getName(), "public,schema2");
 
@@ -307,12 +306,11 @@ public class SchemaTest {
     }
   }
 
-  private void assertColType(PreparedStatement ps, String message, int expected) throws SQLException {
+  private static void assertColType(PreparedStatement ps, String message, int expected) throws SQLException {
     ResultSet rs = ps.executeQuery();
     ResultSetMetaData md = rs.getMetaData();
     int columnType = md.getColumnType(1);
-    assertEquals(message,
-        expected, columnType);
+    assertEquals(expected, columnType, message);
     rs.close();
   }
 
