@@ -5,12 +5,12 @@
 
 package org.postgresql.test.jdbc42;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assume.assumeTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import org.postgresql.core.ServerVersion;
 import org.postgresql.test.TestUtil;
@@ -18,9 +18,9 @@ import org.postgresql.test.jdbc2.BaseTest4;
 import org.postgresql.util.PSQLException;
 import org.postgresql.util.PSQLState;
 
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedClass;
+import org.junit.jupiter.params.provider.MethodSource;
 
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -45,7 +45,8 @@ import java.util.TimeZone;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
-@RunWith(Parameterized.class)
+@ParameterizedClass
+@MethodSource("data")
 public class GetObject310Test extends BaseTest4 {
 
   private static final TimeZone saveTZ = TimeZone.getDefault();
@@ -61,9 +62,8 @@ public class GetObject310Test extends BaseTest4 {
     setBinaryMode(binaryMode);
   }
 
-  @Parameterized.Parameters(name = "binary = {0}")
   public static Iterable<Object[]> data() {
-    Collection<Object[]> ids = new ArrayList<Object[]>();
+    Collection<Object[]> ids = new ArrayList<>();
     for (BinaryMode binaryMode : BinaryMode.values()) {
       ids.add(new Object[]{binaryMode});
     }
@@ -95,7 +95,7 @@ public class GetObject310Test extends BaseTest4 {
   public void testGetLocalDate() throws SQLException {
     assumeTrue(TestUtil.haveIntegerDateTimes(con));
 
-    List<String> zoneIdsToTest = new ArrayList<String>();
+    List<String> zoneIdsToTest = new ArrayList<>();
     zoneIdsToTest.add("Africa/Casablanca"); // It is something like GMT+0..GMT+1
     zoneIdsToTest.add("America/Adak"); // It is something like GMT-10..GMT-9
     zoneIdsToTest.add("Atlantic/Azores"); // It is something like GMT-1..GMT+0
@@ -143,10 +143,10 @@ public class GetObject310Test extends BaseTest4 {
 
   public void localDate(ZoneId zoneId, String date) throws SQLException {
     TimeZone.setDefault(TimeZone.getTimeZone(zoneId));
-    try (Statement stmt = con.createStatement(); ) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","date_column","DATE '" + date + "'"));
+    try (Statement stmt = con.createStatement() ) {
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "date_column", "DATE '" + date + "'"));
 
-      try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "date_column")); ) {
+      try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "date_column")) ) {
         assertTrue(rs.next());
         LocalDate localDate = LocalDate.parse(date);
         assertEquals(localDate, rs.getObject("date_column", LocalDate.class));
@@ -168,10 +168,10 @@ public class GetObject310Test extends BaseTest4 {
     );
 
     for (String time : timesToTest) {
-      try (Statement stmt = con.createStatement(); ) {
-        stmt.executeUpdate(TestUtil.insertSQL("table1","time_with_time_zone_column","time with time zone '" + time + "'"));
+      try (Statement stmt = con.createStatement() ) {
+        stmt.executeUpdate(TestUtil.insertSQL("table1", "time_with_time_zone_column", "time with time zone '" + time + "'"));
 
-        try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_with_time_zone_column")); ) {
+        try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_with_time_zone_column")) ) {
           assertTrue(rs.next());
           OffsetTime offsetTime = OffsetTime.parse(time);
           assertEquals(offsetTime, rs.getObject("time_with_time_zone_column", OffsetTime.class));
@@ -196,8 +196,8 @@ public class GetObject310Test extends BaseTest4 {
    */
   @Test
   public void testGetLocalTime() throws SQLException {
-    try (Statement stmt = con.createStatement(); ) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","time_without_time_zone_column","TIME '04:05:06.123456'"));
+    try (Statement stmt = con.createStatement() ) {
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "time_without_time_zone_column", "TIME '04:05:06.123456'"));
 
       try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_without_time_zone_column"))) {
         assertTrue(rs.next());
@@ -210,7 +210,24 @@ public class GetObject310Test extends BaseTest4 {
         assertDataTypeMismatch(rs, "time_without_time_zone_column", LocalDate.class);
         assertDataTypeMismatch(rs, "time_without_time_zone_column", LocalDateTime.class);
       }
-      stmt.executeUpdate("DELETE FROM table1");
+    }
+  }
+
+  /**
+   * Test the behavior getObject for time columns with value "24:00", which isn't supported by
+   * {@link LocalTime}, and thus gets converted to {@link LocalTime#MAX}
+   */
+  @Test
+  public void testGetLocalTimeMax() throws SQLException {
+    try (Statement stmt = con.createStatement() ) {
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "time_without_time_zone_column", "TIME '24:00'"));
+
+      try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_without_time_zone_column"))) {
+        assertTrue(rs.next());
+        LocalTime localTime = LocalTime.MAX;
+        assertEquals(localTime, rs.getObject("time_without_time_zone_column", LocalTime.class));
+        assertEquals(localTime, rs.getObject(1, LocalTime.class));
+      }
     }
   }
 
@@ -219,15 +236,14 @@ public class GetObject310Test extends BaseTest4 {
    */
   @Test
   public void testGetLocalTimeNull() throws SQLException {
-    try (Statement stmt = con.createStatement(); ) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","time_without_time_zone_column","NULL"));
+    try (Statement stmt = con.createStatement() ) {
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "time_without_time_zone_column", "NULL"));
 
       try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_without_time_zone_column"))) {
         assertTrue(rs.next());
         assertNull(rs.getObject("time_without_time_zone_column", LocalTime.class));
         assertNull(rs.getObject(1, LocalTime.class));
       }
-      stmt.executeUpdate("DELETE FROM table1");
     }
   }
 
@@ -236,8 +252,8 @@ public class GetObject310Test extends BaseTest4 {
    */
   @Test
   public void testGetLocalTimeInvalidType() throws SQLException {
-    try (Statement stmt = con.createStatement(); ) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","time_with_time_zone_column", "TIME '04:05:06.123456-08:00'"));
+    try (Statement stmt = con.createStatement() ) {
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "time_with_time_zone_column", "TIME '04:05:06.123456-08:00'"));
 
       try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "time_with_time_zone_column"))) {
         assertTrue(rs.next());
@@ -245,7 +261,6 @@ public class GetObject310Test extends BaseTest4 {
         assertDataTypeMismatch(rs, "time_with_time_zone_column", LocalDateTime.class);
         assertDataTypeMismatch(rs, "time_with_time_zone_column", LocalDate.class);
       }
-      stmt.executeUpdate("DELETE FROM table1");
     }
   }
 
@@ -256,7 +271,7 @@ public class GetObject310Test extends BaseTest4 {
   public void testGetLocalDateTime() throws SQLException {
     assumeTrue(TestUtil.haveIntegerDateTimes(con));
 
-    List<String> zoneIdsToTest = new ArrayList<String>();
+    List<String> zoneIdsToTest = new ArrayList<>();
     zoneIdsToTest.add("Africa/Casablanca"); // It is something like GMT+0..GMT+1
     zoneIdsToTest.add("America/Adak"); // It is something like GMT-10..GMT-9
     zoneIdsToTest.add("Atlantic/Azores"); // It is something like GMT-1..GMT+0
@@ -305,7 +320,7 @@ public class GetObject310Test extends BaseTest4 {
   public void localTimestamps(ZoneId zoneId, String timestamp) throws SQLException {
     TimeZone.setDefault(TimeZone.getTimeZone(zoneId));
     try (Statement stmt = con.createStatement()) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","timestamp_without_time_zone_column","TIMESTAMP '" + timestamp + "'"));
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "timestamp_without_time_zone_column", "TIMESTAMP '" + timestamp + "'"));
 
       try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "timestamp_without_time_zone_column"))) {
         assertTrue(rs.next());
@@ -338,7 +353,7 @@ public class GetObject310Test extends BaseTest4 {
 
   private void runGetOffsetDateTime(ZoneOffset offset) throws SQLException {
     try (Statement stmt = con.createStatement()) {
-      stmt.executeUpdate(TestUtil.insertSQL("table1","timestamp_with_time_zone_column","TIMESTAMP WITH TIME ZONE '2004-10-19 10:23:54.123456" + offset.toString() + "'"));
+      stmt.executeUpdate(TestUtil.insertSQL("table1", "timestamp_with_time_zone_column", "TIMESTAMP WITH TIME ZONE '2004-10-19 10:23:54.123456" + offset.toString() + "'"));
 
       try (ResultSet rs = stmt.executeQuery(TestUtil.selectSQL("table1", "timestamp_with_time_zone_column"))) {
         assertTrue(rs.next());
